@@ -1,11 +1,11 @@
-#' Creats a flextable object from a dataframe
+#' Creates a flextable object from a dataframe
 #'
 #' @param x A dataframe.
 #' @param delim Delimiter.
 #' @param style Named list that specifies how to style the different parts of
 #' the gt table. Accepted entries are: title, subtitle, header, header_name,
 #' header_level, column_name, group_label, and body. Alternatively, use
-#' "default" to get visOmopResult style, or NULL for gt style
+#' "default" to get visOmopResults style, or NULL for flextable style.
 #' @param na How to display missing values.
 #' @param title Title of the table, or NULL for no title.
 #' @param subtitle Subtitle of the table, or NULL for no subtitle.
@@ -16,23 +16,22 @@
 #' @param groupNameAsColumn Whether to display the group labels as a column
 #' (TRUE) or rows (FALSE).
 #' @param groupOrder Order in which to display group labels.
-#' @param colsToMergeRows specify the names of the columns to vertically merge
-#' when consecutive cells have identical values. Alternatively, use
+#' @param colsToMergeRows Names of the columns to merge vertically
+#' when consecutive row cells have identical values. Alternatively, use
 #' "all_columns" to apply this merging to all columns, or use NULL to indicate
-#' no merging should be applied.
+#' no merging.
 #'
-#' @return flextable object
+#' @return A flextable object.
 #'
 #' @description
-#' Creats a flextable object from a dataframe using as delimiter (`delim`) to span
-#' the header, and the specified styles for different parts of the table.
+#' Creates a flextable object from a dataframe using a delimiter to span
+#' the header, and allows to easily customise table style.
 #'
 #' @examples
-#' \donttest{
 #' mockSummarisedResult() |>
 #'   formatEstimateValue(decimals = c(integer = 0, numeric = 1)) |>
-#'   formatTable(header = c("Study strata", "strata_name", "strata_level"),
-#'               includeHeaderName = FALSE) |>
+#'   formatHeader(header = c("Study strata", "strata_name", "strata_level"),
+#'                includeHeaderName = FALSE) |>
 #'   fxTable(
 #'     style = "default",
 #'     na = "--",
@@ -44,9 +43,8 @@
 #'     groupOrder = c("cohort1", "cohort2"),
 #'     colsToMergeRows = "all_columns"
 #'  )
-#' }
 #'
-#' @return A flextable.
+#' @return A flextable object.
 #'
 #' @export
 #'
@@ -64,19 +62,23 @@ fxTable <- function(
     colsToMergeRows = NULL
 ) {
 
-  # Checks
-  checkmate::assertDataFrame(x)
-  checkmate::assertCharacter(delim, min.chars = 1, len = 1, any.missing = FALSE)
-  checkmate::assertCharacter(na, len = 1, null.ok = TRUE)
-  checkmate::assertCharacter(title, len = 1, null.ok = TRUE, any.missing = FALSE)
-  checkmate::assertCharacter(subtitle, len = 1, null.ok = TRUE, any.missing = FALSE)
-  checkmate::assertCharacter(caption, len = 1, null.ok = TRUE, any.missing = FALSE)
-  checkmate::assertCharacter(groupNameCol, null.ok = TRUE, any.missing = FALSE)
-  checkmate::assertLogical(groupNameAsColumn, len = 1, any.missing = FALSE)
-  checkmate::assertCharacter(groupOrder, null.ok = TRUE, any.missing = FALSE)
-  checkmate::assertCharacter(colsToMergeRows, null.ok = TRUE, any.missing = FALSE)
-  checkColsToMergeRows(x, colsToMergeRows, groupNameCol)
-  style <- checkStyle(style, "fx")
+  # Package checks
+  rlang::check_installed("flextable")
+  rlang::check_installed("officer")
+
+  # Input checks
+  assertTibble(x)
+  assertCharacter(delim, length = 1)
+  assertCharacter(na, length = 1, null = TRUE)
+  assertCharacter(title, length = 1, null = TRUE)
+  assertCharacter(subtitle, length = 1, null = TRUE)
+  assertCharacter(caption, length = 1, null= TRUE)
+  assertCharacter(groupNameCol, null = TRUE)
+  assertLogical(groupNameAsColumn, length = 1)
+  assertCharacter(groupOrder, null = TRUE)
+  assertCharacter(colsToMergeRows, null = TRUE)
+  validateColsToMergeRows(x, colsToMergeRows, groupNameCol)
+  style <- validateStyle(style, "fx")
   if (is.null(title) & !is.null(subtitle)) {
     cli::cli_abort("There must be a title for a subtitle.")
   }
@@ -94,7 +96,11 @@ fxTable <- function(
 
   # na
   if (!is.null(na)){
-    x[is.na(x)] <- na
+    x <- x |>
+      dplyr::mutate(
+        dplyr::across(dplyr::where(~is.numeric(.x)), ~as.character(.x)),
+        dplyr::across(colnames(x), ~ dplyr::if_else(is.na(.x), na, .x))
+      )
   }
 
   # Flextable
@@ -267,7 +273,7 @@ fxStyles <- function(styleName) {
     )
   )
   if (! styleName %in% names(styles)) {
-    warning(glue::glue("{styleName} does not correspon to any of our defined styles. Returning default."),
+    warning(paste0(styleName, " does not correspon to any of our defined styles. Returning default."),
             call. = FALSE)
     styleName <- "default"
   }
