@@ -16,7 +16,7 @@
 #' @description
 #' `r lifecycle::badge("experimental")`
 #' Provides tools for obtaining a tidy version of a summarised_result object. If
-#' the summarised results object contains settings, these will be tranformed
+#' the summarised results object contains settings, these will be transformed
 #' into columns.
 #'
 #' @export
@@ -71,7 +71,7 @@ tidy.summarised_result <- function(x,
     result_out <- result_out |>
       dplyr::select(-"estimate_type") |>
       tidyr::pivot_wider(
-        names_from = pivotEstimatesBy,
+        names_from = dplyr::all_of(pivotEstimatesBy),
         values_from = "estimate_value",
         names_glue = nameStyle
       ) |>
