@@ -1,8 +1,5 @@
 
 validateResult <- function(x, call = parent.frame()) {
-  if (inherits(x, "omop_result")) {
-    return(x)
-  }
   xn <- tryCatch(
     omopgenerics::newSummarisedResult(x),
     error = function(e){NULL}
@@ -10,10 +7,6 @@ validateResult <- function(x, call = parent.frame()) {
   if (!is.null(xn)) {
     return(xn)
   }
-  xn <- tryCatch(
-    omopgenerics::newComparedResult(x),
-    error = function(e){NULL}
-  )
   if (!is.null(xn)) {
     return(xn)
   }
@@ -34,7 +27,7 @@ validateDecimals <- function(result, decimals) {
     cli::cli_abort(errorMesssage)
   } else if (!all(names(decimals) %in% c(nm_type, nm_name))) { # not correctly named
     conflict_nms <- names(decimals)[!names(decimals) %in% c(nm_type, nm_name)]
-    cli::cli_abort(glue::glue("{paste0(conflict_nms, collapse = ", ")} do not correspont to estimate_type or estimate_name values."))
+    cli::cli_abort(paste0(paste0(conflict_nms, collapse = ", "), " do not correspont to estimate_type or estimate_name values."))
   } else if (length(decimals) == 1 & is.null(names(decimals))) { # same number to all
     decimals <- rep(decimals, length(nm_type))
     names(decimals) <- nm_type
@@ -47,34 +40,56 @@ validateDecimals <- function(result, decimals) {
 }
 
 validateEstimateNameFormat <- function(format, call = parent.frame()) {
-  if (length(stringr::str_match_all(format, "(?<=\\<).+?(?=\\>)") |> unlist()) == 0) {
-    cli::cli_abort("format input does not contain any estimate name indicated by <...>.")
+  if (!is.null(format)) {
+    if (length(format) > 0){
+      if (length(regmatches(format, gregexpr("(?<=\\<).+?(?=\\>)", format, perl = T)) |> unlist()) == 0) {
+        cli::cli_abort("format input does not contain any estimate name indicated by <...>.")
+      }
+    } else {
+      format <- NULL
+    }
   }
+  return(format)
 }
 
-checkStyle <- function(style, tableFormatType) {
+validateStyle <- function(style, tableFormatType) {
   if (is.list(style) | is.null(style)) {
-    checkmate::assertList(style, null.ok = TRUE, any.missing = FALSE)
+    assertList(style, null = TRUE, named = TRUE)
   } else if (is.character(style)) {
-    checkmate::assertCharacter(style, min.chars = 1, any.missing = FALSE, max.len = 1)
+    assertCharacter(style, null = TRUE)
     eval(parse(text = paste0("style <- ", tableFormatType, "Styles(styleName = style)")))
   } else {
-    cli::cli_abort("Style must be one of 1) a named list of flextable styling function,
-                   2) the string 'default' for our default style, or 3) NULL to indicate no styling.")
+    if (tableFormatType == "fx") {
+      tableFormatType <- "flextable"
+    }
+    cli::cli_abort(paste0("Style must be one of 1) a named list of ", tableFormatType, " styling functions,
+                   2) the string 'default' for visOmopResults default style, or 3) NULL to indicate no styling."))
   }
   return(style)
 }
 
-checkColsToMergeRows <- function(x, colsToMergeRows, groupNameCol) {
+validateColsToMergeRows <- function(x, colsToMergeRows, groupNameCol) {
   if (!is.null(colsToMergeRows)) {
     if (any(colsToMergeRows %in% groupNameCol)) {
       cli::cli_abort("groupNameCol and colsToMergeRows must have different column names.")
     }
     ind <- ! colsToMergeRows %in% c(colnames(x), "all_columns")
     if (sum(ind) == 1) {
-      warning(glue::glue("{colsToMergeRows[ind]} is not a column in the dataframe."))
+      warning(paste0(colsToMergeRows[ind], " is not a column in the dataframe."))
     } else if (sum(ind) > 1) {
-      warning(glue::glue("{colsToMergeRows[ind]} are not columns in the dataframe."))
+      warning(paste0(colsToMergeRows[ind], " are not columns in the dataframe."))
     }
   }
 }
+
+validateDelim <- function(delim) {
+  if (!rlang::is_character(delim)) {
+    cli::cli_abort("The value supplied for `delim` must be of type `character`.")
+  }
+  if (length(delim) != 1) {
+    cli::cli_abort("`delim` must be a single value.")
+  }
+  if (nchar(delim) != 1) {
+    cli::cli_abort("The value supplied for `delim` must be a single character.")
+  }
+}
